@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 # cython: language_level=3, always_allow_keywords=True
 
-## Copyright 1999-2014 by LivingLogic AG, Bayreuth/Germany
-## Copyright 1999-2014 by Walter Dörwald
+## Copyright 1999-2019 by LivingLogic AG, Bayreuth/Germany
+## Copyright 1999-2019 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
@@ -55,7 +55,7 @@ class EmptyElementWithContentWarning(SIMSWarning):
 		self.path = tuple(path)
 
 	def __str__(self):
-		return "{} doesn't allow content".format(self.path[-1]._str())
+		return f"{self.path[-1]._str()} doesn't allow content"
 
 
 class WrongElementWarning(SIMSWarning):
@@ -69,7 +69,7 @@ class WrongElementWarning(SIMSWarning):
 		self.badnode = badnode
 
 	def __str__(self):
-		return "{} may not contain {}".format(self.path[-1]._str(), self.badnode._str())
+		return f"{self.path[-1]._str()} may not contain {self.badnode._str()}"
 
 
 class ElementWarning(SIMSWarning):
@@ -83,7 +83,7 @@ class ElementWarning(SIMSWarning):
 		self.badnode = badnode
 
 	def __str__(self):
-		return "{} may not contain other elements".format(self.path[-1]._str())
+		return f"{self.path[-1]._str()} may not contain other elements"
 
 
 class IllegalTextWarning(SIMSWarning):
@@ -96,7 +96,7 @@ class IllegalTextWarning(SIMSWarning):
 		self.badnode = badnode
 
 	def __str__(self):
-		return "{} may not contain text".format(self.path[-1]._str())
+		return f"{self.path[-1]._str()} may not contain text"
 
 
 class AnyWarning(SIMSWarning):
@@ -109,7 +109,7 @@ class AnyWarning(SIMSWarning):
 		self.warnings = warnings
 
 	def __str__(self):
-		return " or ".join("{}".format(" and ".join("({})".format(warning) for warning in warnings)) for warnings in self.warnings)
+		return " or ".join(" and ".join(f"({warning})" for warning in warnings) for warnings in self.warnings)
 
 
 def badtext(node):
@@ -123,7 +123,7 @@ def badtext(node):
 	return False
 
 
-class Empty(object):
+class Empty:
 	"""
 	This validator checks that an element has no content.
 	"""
@@ -139,9 +139,9 @@ class Empty(object):
 				yield EmptyElementWithContentWarning(path)
 
 
-class Transparent(object):
+class Transparent:
 	"""
-	This validator implements the "transparent" content model of HTML5:
+	This validator implements the "transparent" content model of HTML5.
 	"""
 	empty = False
 
@@ -155,7 +155,7 @@ class Transparent(object):
 			yield from model.validate(path)
 
 
-class NoElements(object):
+class NoElements:
 	"""
 	This validator checks that an element does not have child elements from the
 	same namespace.
@@ -176,7 +176,7 @@ class NoElements(object):
 					yield ElementWarning(path, child)
 
 
-class NoElementsOrText(object):
+class NoElementsOrText:
 	"""
 	This validator checks that an element does have neither child elements
 	from the same namespace nor real (i.e. not-whitespace) text nodes.
@@ -199,7 +199,7 @@ class NoElementsOrText(object):
 					yield ElementWarning(path, child)
 
 
-class Elements(object):
+class Elements:
 	"""
 	This validator checks that an element does have neither child elements
 	from any of the namespaces of those elements specified in the constructor
@@ -217,7 +217,8 @@ class Elements(object):
 		self.elements = elements
 
 	def __repr__(self):
-		return "Elements({})".format(", ".join("{0.__module__}.{0.__name__}".format(cls) for cls in self.elements))
+		elements = ", ".join(f"{cls.__module__}.{cls.__qualname__}" for cls in self.elements)
+		return f"Elements({elements})"
 
 	def validate(self, path):
 		"""
@@ -252,7 +253,8 @@ class ElementsOrText(Elements):
 		self.elements = elements
 
 	def __repr__(self):
-		return "ElementsOrText({})".format(", ".join("{0.__module__}.{0.__name__}".format(cls) for cls in self.elements))
+		elements = ", ".join(f"{cls.__module__}.{cls.__name__}" for cls in self.elements)
+		return f"ElementsOrText({elements})"
 
 	def validate(self, path):
 		"""
@@ -269,7 +271,7 @@ class ElementsOrText(Elements):
 						yield WrongElementWarning(path, child)
 
 
-class NotElements(object):
+class NotElements:
 	"""
 	This validator checks that an element doesn't contain any of the specified
 	elements.
@@ -284,7 +286,8 @@ class NotElements(object):
 		self.elements = elements
 
 	def __repr__(self):
-		return "NotElements({})".format(", ".join("{0.__module__}.{0.__name__}".format(cls) for cls in self.elements))
+		elements = ", ".join(f"{cls.__module__}.{cls.__name__}" for cls in self.elements)
+		return f"NotElements({elements})"
 
 	def validate(self, path):
 		node = path[-1]
@@ -294,7 +297,7 @@ class NotElements(object):
 					yield WrongElementWarning(path, child)
 
 
-class All(object):
+class All:
 	"""
 	This meta validator checks that all its child validators declare the content
 	of the element to be valid.
@@ -305,7 +308,8 @@ class All(object):
 		self.validators = validators
 
 	def __repr__(self):
-		return "<{0.__class__.__module__}:{0.__class__.__qualname__} {1} at {2:#x}>".format(self, " ".join(repr(validator) for validator in self.validators), id(self))
+		validators = " ".join(repr(validator) for validator in self.validators)
+		return f"<{self.__class__.__module__}:{self.__class__.__qualname__} {validators} at {id(self):#x}>"
 
 	def validate(self, path):
 		seen = set()
@@ -316,7 +320,7 @@ class All(object):
 					seen.add(warning)
 
 
-class Any(object):
+class Any:
 	"""
 	This meta validator checks that at least one of its child validators declares
 	the content of the element to be valid.
@@ -327,7 +331,8 @@ class Any(object):
 		self.validators = validators
 
 	def __repr__(self):
-		return "<{0.__class__.__module__}:{0.__class__.__qualname__} {1} at {2:#x}>".format(self, " ".join(repr(validator) for validator in self.validators), id(self))
+		validators = " ".join(repr(validator) for validator in self.validators)
+		return f"<{self.__class__.__module__}:{self.__class__.__qualname__} {validators} at {id(self):#x}>"
 
 	def validate(self, path):
 		if self.validators:
