@@ -2,15 +2,15 @@
 # -*- coding: utf-8 -*-
 # cython: language_level=3, always_allow_keywords=True
 
-## Copyright 2004-2017 by LivingLogic AG, Bayreuth/Germany
-## Copyright 2004-2017 by Walter Dörwald
+## Copyright 2004-2019 by LivingLogic AG, Bayreuth/Germany
+## Copyright 2004-2019 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
 ## See ll/xist/__init__.py for the license
 
 
-import sys, os, datetime, collections, decimal
+import sys, os, datetime, decimal
 
 import pytest
 
@@ -35,7 +35,7 @@ class Data:
 		self._objects = None
 
 	def _make(self):
-		self._objects = collections.OrderedDict()
+		self._objects = {}
 		db = orasql.connect(self.dbname)
 		# get all definitions
 		# (this tests that :meth:`objects`, :meth:`references` and :meth:`referencedby` run to completion)
@@ -51,6 +51,11 @@ class Data:
 
 @pytest.fixture(scope="module")
 def db_data(request):
+	"""
+	Return a :class:`Data` object. :meth:`Data.objects` returns a dictionary
+	object containing information about all database objects and the references
+	between those objects.
+	"""
 	return Data(dbname)
 
 
@@ -75,7 +80,7 @@ def test_connection_connectstring():
 	db = orasql.connect(dbname)
 	user = dbname.split("/")[0]
 	name = dbname.split("@")[1]
-	assert "{}@{}".format(user, name) == db.connectstring()
+	assert f"{user}@{name}" == db.connectstring()
 
 
 @pytest.mark.db
@@ -241,6 +246,24 @@ def test_procedure_nonexistant():
 			orasql.Procedure("DOESNOTEXIST")(db.cursor())
 
 
+@pytest.mark.db
+def test_jobs():
+	if dbname:
+		db = orasql.connect(dbname)
+		for obj in orasql.Job.objects(db):
+			obj.createsql()
+			obj.dropsql()
+
+
+@pytest.mark.db
+def test_job_classes():
+	if dbname:
+		db = orasql.connect(dbname)
+		for obj in orasql.JobClass.objects(db):
+			obj.createsql()
+			obj.dropsql()
+
+
 @pytest.mark.db
 def test_createorder(db_data):
 	# check that the default output order of :meth:`objects` (i.e. create order) works
@@ -256,7 +279,7 @@ def test_createorder(db_data):
 def test_scripts_oracreate():
 	if dbname:
 		# Test oracreate without executing anything
-		args = "--color=yes --verbose=yes --seqcopy=yes {}".format(dbname)
+		args = f"--color=yes --verbose=yes --seqcopy=yes {dbname}"
 		oracreate.main(args.split())
 
 
@@ -264,7 +287,7 @@ def test_scripts_oracreate():
 def test_scripts_oradrop():
 	if dbname:
 		# Test oradrop without executing anything
-		args = "--color=yes --verbose=yes {}".format(dbname)
+		args = f"--color=yes --verbose=yes {dbname}"
 		oradrop.main(args.split())
 
 
@@ -273,8 +296,8 @@ def test_scripts_oradiff():
 	if dbname:
 		# Test oradiff (not really: we will not get any differences)
 		allargs = [
-			"--color=yes --verbose=yes {0} {0}".format(dbname),
-			"--color=yes --verbose=yes {0} {0} -mfull".format(dbname),
+			f"--color=yes --verbose=yes {dbname} {dbname}",
+			f"--color=yes --verbose=yes {dbname} {dbname} -mfull",
 		]
 		for args in allargs:
 			oradiff.main(args.split())
@@ -284,7 +307,7 @@ def test_scripts_oradiff():
 def test_scripts_oramerge():
 	if dbname:
 		# Test oramerge (not really: we will not get any differences)
-		args = "--color=yes --verbose=yes {0} {0} {0}".format(dbname)
+		args = f"--color=yes --verbose=yes {dbname} {dbname} {dbname}"
 		oramerge.main(args.split())
 
 
@@ -292,7 +315,7 @@ def test_scripts_oramerge():
 def test_scripts_oragrant():
 	if dbname:
 		# Test oragrant
-		args = "--color=yes {0}".format(dbname)
+		args = f"--color=yes {dbname}"
 		oragrant.main(args.split())
 
 
@@ -300,7 +323,7 @@ def test_scripts_oragrant():
 def test_scripts_orafind():
 	if dbname:
 		# Test orafind
-		args = "--ignore-case yes --color=yes {0} foo".format(dbname)
+		args = f"--ignore-case yes --color=yes {dbname} foo"
 		orafind.main(args.split())
 
 
@@ -308,7 +331,7 @@ def test_scripts_orafind():
 def test_scripts_oradelete():
 	if dbname:
 		# Test oradelete without executing anything
-		args = "--color=yes --verbose=yes {}".format(dbname)
+		args = f"--color=yes --verbose=yes {dbname}"
 		oradelete.main(args.split())
 
 
@@ -316,7 +339,7 @@ def test_scripts_oradelete():
 def test_scripts_orareindex():
 	if dbname:
 		# Test orareindex without executing anything
-		args = "--color=yes --verbose=yes {}".format(dbname)
+		args = f"--color=yes --verbose=yes {dbname}"
 		orareindex.main(args.split())
 
 
@@ -377,10 +400,10 @@ def test_fetch(db_data):
 			# fetch only a few records
 			db = orasql.connect(dbname)
 			c = db.cursor()
-			c.execute("select * from {}".format(obj.name))
+			c.execute(f"select * from {obj.name}")
 			c.readlobs = False
 			c.fetchone()
-			c.execute("select * from {}".format(obj.name))
+			c.execute(f"select * from {obj.name}")
 			c.readlobs = True
 			c.fetchone()
 			break
@@ -388,7 +411,8 @@ def test_fetch(db_data):
 
 @pytest.mark.db
 def test_url():
-	u = url.URL("oracle://{}/".format(dbname.replace("/", ":")))
+	dburl = dbname.replace("/", ":")
+	u = url.URL(f"oracle://{dburl}/")
 	assert u.isdir()
 	assert u.mimetype() == "application/octet-stream"
 	u.owner()
@@ -398,7 +422,7 @@ def test_url():
 	u.files()
 	u.dirs()
 
-	u = url.URL("oracle://{}/procedure/ORASQL_TESTPROCEDURE".format(dbname.replace("/", ":")))
+	u = url.URL(f"oracle://{dburl}/procedure/ORASQL_TESTPROCEDURE")
 	assert u.isfile()
 	assert u.mimetype() == "text/x-oracle-procedure"
 	u.owner()
